@@ -180,7 +180,7 @@ class AppMenuButtonRightClickMenu extends Applet.AppletPopupMenu {
                 let defualtPlaces = this.listDefaultPlaces();
                 let bookmarks = this.listBookmarks();
                 let devices = this.listDevices();
-                let places = defualtPlaces.concat(bookmarks).concat(devices);
+                let places = [...defualtPlaces, ...bookmarks, ...devices];
                 let handlePlaceLaunch = (item, i) => {
                     this.signals.connect(item, 'activate', () => places[i].launch());
                 };
@@ -274,14 +274,6 @@ class AppMenuButtonRightClickMenu extends Applet.AppletPopupMenu {
                 }
                 this.addMenuItem(new PopupMenu.PopupSeparatorMenuItem());
             }
-            if (this.state.settings.launchNewInstance && (!actions || actions.length === 0) && !isWindowBacked) {
-                item = createMenuItem({label: _('New Window'), icon: 'window-new'});
-                this.signals.connect(item, 'activate', () => this.groupState.trigger('launchNewInstance'));
-                this.addMenuItem(item);
-                if (!actions || actions.length === 0) {
-                    this.addMenuItem(new PopupMenu.PopupSeparatorMenuItem());
-                }
-            }
         }, () => {
             if (isWindowBacked) {
                 this.addMenuItem(new PopupMenu.PopupSeparatorMenuItem());
@@ -352,6 +344,7 @@ class AppMenuButtonRightClickMenu extends Applet.AppletPopupMenu {
                 });
             }
             this.addMenuItem(item);
+            item.setSensitive(this.groupState.lastFocused.can_maximize());
 
             if (this.groupState.metaWindows && this.groupState.metaWindows.length > 1) {
                 // Close others
